#
# spec file for package weechat
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           weechat
Version:        4.3.1
Release:        1.3
Summary:        Multi-protocol extensible Chat Client
License:        GPL-3.0-or-later
Group:          Productivity/Networking/IRC
URL:            https://weechat.org
Source:         https://weechat.org/files/src/%{name}-%{version}.tar.xz
Source1:        weechat.desktop
Source2:        https://weechat.org/files/src/%{name}-%{version}.tar.xz.asc
Source3:        %{name}.keyring
Source4:        %{name}.changes
BuildRequires:  ca-certificates
BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  gcc-c++
BuildRequires:  grep
BuildRequires:  hicolor-icon-theme
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpg-error-devel
BuildRequires:  libtool
BuildRequires:  libzstd-devel
BuildRequires:  lzo-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  ruby-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(enchant)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libcjson)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(tcl)
Requires:       ca-certificates
Requires:       hicolor-icon-theme
Recommends:     %{name}-lang = %{version}
# without scripts it is a bit annoying
Recommends:     %{name}-perl = %{version}
Recommends:     %{name}-python = %{version}
Obsoletes:      %{name}-guile < 2.6

%description
WeeChat (Wee Enhanced Environment for Chat) is a free chat client, fast and light, designed for many operating systems. It is highly customizable and extensible with scripts.

Homepage: https://weechat.org/

%lang_package

%package devel
Summary:        Development Environment for %{name} Plugins
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Development environment for authoring %{name} plugins.

%package lua
Summary:        Lua Scripting Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}

%description lua
Support for %{name} scripts written in the Lua language.

%package perl
Summary:        Perl Scripting Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}
%{?libperl_requires}

%description perl
Support for %{name} scripts written in the Perl language.

%package python
Summary:        Python Scripting Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}

%description python
Support for %{name} scripts written in the Python language.

%package tcl
Summary:        Tcl Scripting Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}

%description tcl
Support for %{name} scripts written in the Tcl language.

%package ruby
Summary:        Ruby Scripting Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}

%description ruby
Support for %{name} scripts written in the Ruby language.

%package spell
Summary:        Aspell and Enchant Spell-Checking Support for %{name}
Group:          Productivity/Networking/IRC
Requires:       %{name} = %{version}
Supplements:    (%{name} and enchant-2-backend-hunspell)
Obsoletes:      %{name}-aspell < %{version}
Provides:       %{name}-aspell = %{version}

%description spell
Spell-checking support for %{name}, using the aspell and enchant libraries.

%prep
%autosetup -p1
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE4}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find . -name '*.[ch]' -exec sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" "{}" "+"

%build
export CFLAGS="%{optflags}"
# Tests require cpputest package
# no-undefined for perl seem not to work as desired
%cmake \
    -DLIBDIR="%{_libdir}" \
    -DENABLE_PYTHON=ON \
    -DPYTHON_LIBRARY="%{_libdir}/libpython%{py3_ver}m.so" \
    -DENABLE_ENCHANT=ON \
    -DENABLE_GUILE=OFF \
    -DENABLE_JAVASCRIPT=OFF \
    -DENABLE_PHP=OFF \
    -DCA_FILE=%{_sysconfdir}/ssl/ca-bundle.pem
%cmake_build

%install
%cmake_install

install -D -m 0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%suse_update_desktop_file -r "%{name}" Network IRCClient

%find_lang "%{name}" --with-man

%files
%doc AUTHORS.adoc ChangeLog.adoc Contributing.adoc
%doc README.adoc ReleaseNotes.adoc
%license COPYING
%{_bindir}/weechat-curses
%{_bindir}/weechat-headless
%{_bindir}/weechat
%dir %{_libdir}/weechat
%dir %{_libdir}/weechat/plugins
%{_libdir}/weechat/plugins/alias.so
%{_libdir}/weechat/plugins/buflist.so
%{_libdir}/weechat/plugins/charset.so
%{_libdir}/weechat/plugins/exec.so
%{_libdir}/weechat/plugins/fifo.so
%{_libdir}/weechat/plugins/irc.so
%{_libdir}/weechat/plugins/logger.so
%{_libdir}/weechat/plugins/relay.so
%{_libdir}/weechat/plugins/script.so
%{_libdir}/weechat/plugins/trigger.so
%{_libdir}/weechat/plugins/xfer.so
%{_libdir}/weechat/plugins/fset.so
%{_libdir}/weechat/plugins/typing.so
%{_datadir}/applications/weechat.desktop
%{_datadir}/icons/hicolor/*/apps/weechat.png

%files -f "%{name}.lang" lang
%license COPYING

%files devel
%license COPYING
%{_includedir}/weechat
%{_libdir}/pkgconfig/weechat.pc

%files lua
%license COPYING
%{_libdir}/weechat/plugins/lua.so

%files perl
%license COPYING
%{_libdir}/weechat/plugins/perl.so

%files python
%license COPYING
%{_libdir}/weechat/plugins/python.so

%files tcl
%license COPYING
%{_libdir}/weechat/plugins/tcl.so

%files ruby
%license COPYING
%{_libdir}/weechat/plugins/ruby.so

%files spell
%license COPYING
%{_libdir}/weechat/plugins/spell.so

%changelog
* Sun Jun  2 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Update to version 4.3.1:
  * irc: close /list buffer when the server buffer is closed (#2121)
  * xfer: fix send of data on the DCC chat buffer after /upgrade if the buffer was opened before the upgrade (#2092)
  * php: fix return value of function hdata_longlong
  * tcl: fix return value of function hdata_longlong (#2119)
  * core: fix detection of libgcrypt ≥ 1.11 (debian #1071960)
  * core, relay: fix include directory of libcjson and libzstd
  * tests: fix relay tests on s390x (#2118)
  * tests: fix check of php plugin (#2117)
  * tests: fix compilation of tests on Fedora 40 (#2116)
  * tests: fix compilation of tests on Rocky 9.4
- From version 4.3.0:
  - Changed:
  * reaking: irc: add server option "autojoin_delay" (delay before autojoin), use option "command_delay" before execution of the command (#862)
  * breaking: irc: rename option irc.color.item_channel_modes to weechat.color.status_modes
  * breaking: irc: add option -all in command /allchan, do not execute command on parted channels by default (#2085)
  * breaking: relay: rename option relay.weechat.commands to relay.network.commands and change default to *,!quit (#2066)
  * breaking: relay: change option type relay.look.auto_open_buffer to string (#2066)
  * breaking: core: add buffer properties "input_prompt" and "modes", used to display bar items (#2066)
  * breaking: core: add bar item "lag" to display lag on relay remote buffers (#2066)
  * breaking: core: send signal "buffer_line_added" on buffers with free content
  * breaking: core: convert option weechat.look.hotlist_sort to a list of fields (#2097)
  * breaking: core: rename variables with creation time in hdata "hotlist": "creation_time.tv_sec" to "time" and "creation_time.tv_usec" to "time_usec"
  * breaking: api: return -1 or 1 if one input string is NULL and not the other in string comparison functions
  * breaking: api: use whole replacement string instead of first char in function string_remove_color
  * core: use nick offline color for nick in action message
  * core: display a specific message when the value of option is unchanged after /set command
  * core: add variable ${highlight} in option weechat.look.buffer_time_format (#2079)
  * core: reintroduce help on the variables and operators in /help eval (#2005)
  * core: allow case insensitive search of partial buffer name with (?i)name in command /buffer
  * core: use function util_strftimeval in evaluation of expression date:xxx
  * fset: allow filename starting with "~" in command /fset -export
  * irc: store lag in channel and private buffers (local variable "lag"), in addition to the server buffer
  * irc: allow range in commands /unban and /unquiet (#2113)
  * tcl: add support of Tcl 9.0 (#2075)
  - Added:
  * relay: add "api" protocol (HTTP REST API), add options relay.look.display_clients, relay.api.remote_get_lines and relay.network.time_window (#2066)
  * relay: add command /remote to connect to remote WeeChat relay servers (#2066)
  * relay: add support of websocket extension "permessage-deflate" (#1549)
  * core, api: add unique identifier "id" in buffer and nicklist (group and nick), add function "hdata_longlong", allow search by buffer id in function buffer_search, allow search by group and nick id in functions nicklist_search_group and nicklist_search_nick (#2081)
  * core: add support of XDG "state" directory (#2106, #1747)
  * core: add support of SGR mouse events (#2082)
  * fset: add option -import in command /fset
  * core: add option -s in command /command to execute multiple commands separated by semicolons
  * core: add option malloc_trim in command /sys
  * core: add option weechat.look.config_permissions (#2057)
  * core: add option weechat.look.highlight_prefix (#2079)
  * core: add option weechat.completion.case_sensitive
  * api: add functions config_option_get_{string|pointer} and config_{boolean|integer|string|color|enum}_inherited in scripting API
  * api: add modifier "color_decode" to decode WeeChat colors with a replacement string
  * api: add support of base64url in encode/decode functions
  * api: add support of specifier %%! for timestamp in function util_strftimeval
  * api: add info "plugin_loaded"
  * script: add option enable in command /script
  * script: add info "script_loaded"
  - Fixed:
  * core: fix conversion of WeeChat colors to ANSI colors: "default", "bar_fg", "bar_bg", "bar_delim"
  * core: fix recursive search of group in nicklist
  * core: use nick offline highlight color for prefix of action message when the nick is offline with a highlight
  * core: add missing hdata name "buffer" in hdata "hotlist"
  * core: fix reset to initial scroll position after search of text in buffer (#2093)
  * core: add missing mouse events "alt-ctrl-button2" and "alt-ctrl-button3"
  * core: remove trailing directory separators in home directories (#2070)
  * exec: remove trailing space on buffers with free content when line numbers are not displayed
  * exec: add missing exec tags in lines of buffers with free content (#2086)
  * irc: fix crash in split of IRC message containing a newline if the server is not given
  * irc: fix display of reply for CTCP request received on a channel when capability echo-message is enabled
  * irc: display CTCP reply to a nick in server buffer instead of channel
  * irc: add missing tags on self action messages when capability echo-message is enabled (#2074)
  * irc: don't strip monospace color code 0x11 from incoming messages (#2073)
  * irc: fix random date displayed when a received message contains tags but no "time" (#2064)
  * lua: fix freeze on call to "debug.debug" (#1906, #1907)
  * python: fix truncation of unsigned long long integer returned by function string_parse_size
  * relay: set the last IRC client disconnection time only after a successful connection (#2103)
  * script: always display list of scripts when searching scripts with /script search (#2077)
  * script: fix default mouse keys (#2076)
  * scripts: fix crash on script unload when a hook is created in a buffer close callback (#2067)
  * tcl: fix truncation of long integer returned by function hdata_long
  * trigger: fix memory leak when adding a new trigger with /trigger command
- From version 4.2.3:
  * xfer: fix send of data on the DCC chat buffer after /upgrade if the buffer was opened before the upgrade (#2092)
  * irc: fix crash in split of IRC message containing a newline if the server is not given
  * core, relay: fix include directory of libzstd
* Sun Apr 28 2024 Dirk Müller <dmueller@suse.com>
- update to 4.2.2:
  * core: fix reset to initial scroll position after search
    of text in buffer (issue #2093)
  * core: add missing mouse events "alt-ctrl-button2" and
    "alt-ctrl-button3"
  * exec: remove trailing space on buffers with free content when
    line numbers are not displayed
  * exec: add missing exec tags in lines of buffers with free
    content (issue #2086)
  * irc: add missing tags on self action messages when capability
    echo-message is enabled (issue #2074)
  * python: fix truncation of unsigned long long integer returned
    by function string_parse_size
  * relay: set the last IRC client disconnection time only after
    a successful connection (issue #2103)
  * script: always display list of scripts when searching scripts
    with `/script search` (issue #2077)
  * script: fix default mouse keys (issue #2076)
  * scripts: fix crash on script unload when a hook is created
    in a buffer close callback (issue #2067)
  * tcl: fix truncation of long integer returned by function
    hdata_long
  * trigger: fix memory leak when adding a new trigger with
    `/trigger` command
* Tue Feb  6 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.2.1:
  + irc: fix random date displayed when a received message contains
    tags but no "time".
- Changes from version 4.2.0:
  + core:
  - add variable "opening" in buffer, do not send buffer signals
    when the buffer is opening.
  - store microseconds in buffer lines.
  - evaluate expressions even when the suffix is missing ("}" by
    default).
  - add syntax highlighting in evaluation of expressions with
    raw_hl:string and hl:string, add option
    weechat.color.eval_syntax_colors.
  - add option search_history in command /input, add key Ctrl+r
    to search in commands history, add key context "histsearch".
  - add option weechat.look.buffer_search_history.
  - add key Ctrl+o to send command found and insert next one in
    input.
  - add buffer variables "text_search_direction",
    "text_search_history" and "text_search_ptr_history".
  - move key Ctrl+r to Ctrl+s.
  - move key Ctrl+s, Ctrl+u to Alt+Shift+U.
  - display only version with command /version, add options -o
    and -ol in command /upgrade.
  - add number of processes in command /sys waitpid.
  + core, alias, trigger: allow wildcard in commands /bar, /item,
    /proxy, /alias and /trigger.
  + api: add functions util_strftimeval, util_parse_time,
    printf_datetime_tags, printf_y_datetime_tags.
  + api:
  - add argument "date_usec" in hook_print callback.
  - api: add property "type" in function buffer_get_string.
  - api: add info "mouse".
  + buflist: jump to previous/next buffer displayed in buflist item
    with ctrl+wheel up/down on a buflist item.
  + irc:
  - add option irc.look.display_host_wallops.
  - add server option "anti_flood" (now in milliseconds), remove
    server options "anti_flood_prio_{high|low}".
  - add option irc.look.list_buffer.
  - change default value of server option "tls_priorities" to
    NORMAL.
  - add support of RGB colors in messages, add option
    irc.color.term_remap.
  - add tags "nick_xxx" and "host_xxx" in all messages, including
    self and server messages.
  - add option irc.look.ignore_tag_messages.
  + relay: change default value of option
    relay.network.tls_priorities to NORMAL.
  + trigger: change format of variables ${tg_date} from "%%Y-%%m-%%d
    %%H:%%M:%%S" to "%%FT%%T.%%f".
  + trigger: rename local variable "trigger_filter" to "filter" on
    monitor buffer.
  + ruby: add detection of Ruby 3.3.
- Changes from version 4.1.3:
  + core: fix crash on plugin reload when using musl libc.
  + core: fix infinite loop in display when the chat area is too
    small.
  + irc: check if arguments are not NULL in some infos.
  + irc: fix info "irc_is_message_ignored".
  + irc: fix display of self messages when the message split fails
    due to inconsistent max lengths sent by the server in message
    005.
* Sun Dec 10 2023 Wang Jun <badboywj@gmail.com>
- Update to version 4.1.2
  * core: fix value of buffer variable "num_history" when the
    value defined in option weechat.history.max_commands is reached
  * core: remove incorrect warning when binding keys kbd:[F10]
    to kbd:[F20] (issue #2039)
  * core: fix memory leak when config version is invalid or
    not supported
  * core: fix crash when "config_version" is present in a
    configuration file without a value
  * core: display an error on startup if environment variable
    "HOME" is not set
  * irc: remove trailing "\r\n" in signals "irc_out" and
    "irc_outtags" when messages are queued
  * irc: fix target buffer of IRC message 337 (whois reply: "is
    hiding their idle time")
  * relay: close properly connection with the IRC client in case
    of server disconnection (issue #2038)
  * ruby: fix use of NULL variable when displaying exception
- changes from version 4.1.1
  * core: fix crash when a custom bar item name is already used
    by a default bar item (issue #2034)
  * core: fix random timeouts when a lot of concurrent processes
    are launched with hook_process (issue #2033)
  * irc: revert compute of nick colors to case sensitive way,
    deprecate again infos "irc_nick_color" and "irc_nick_color_name"
    (issue #194, issue #2032)
  * core: make libintl.h required if CMake option ENABLE_NLS is
    enabled (issue #2031)
- changes from version 4.1.0
  * core: add completion "eval_variables", used in completion
    of `/eval`
  * core: add command `/sys` to show resource limits/usage and
    suspend WeeChat process, add key kbd:[Ctrl+z] to suspend
    WeeChat (issue #985)
  * core: ignore key bindings with empty command
  * core: add support of quotes in commands `/key bind` and
    `/key bindctxt`
  * core: evaluate command given to `/repeat` with contextual
    variables (issue #2007)
  * core: add option `callbacks` in command `/debug`
  * core: add option type "enum" (issue #1973)
  * core: add options weechat.buffer.* to save buffer properties
    set by user, add option `setauto` in command `/buffer`
    (issue #352)
  * core: add parameters and key bindings to move to edges of
    current area with commands `/cursor go` and `/cursor move`
    (issue #1282)
  * core: add variables "_chat_focused_line_bol" and
    "_chat_focused_line_eol" in focus data (issue #1955)
  * api: add function hook_url, add option `url` in command
    `/debug` (issue #1723)
  * api: add support of path to variable and hashtable comparison
    in function hdata_compare (issue #1066)
  * api: add infos "nick_color_ignore_case" and
    "nick_color_name_ignore_case" (issue #194)
  * api: add info "buffer" (issue #1962)
  * buflist: add support of item names in command `/buflist refresh`,
    add completions "buflist_items" and "buflist_items_used"
  * buflist: increase max number of buflist items from 3 to
    5 (issue #1703)
  * fset: add variable `allowed_values` in options, add options
    fset.color.allowed_values and fset.color.allowed_values_selected
  * fset: allow long type name in type filter
  * irc: add count for all nick modes in output of `/names`
    (issue #97, issue #2020)
  * irc: add count and mode filter in command `/names` (issue #98)
  * irc: compute color in case insensitive way, reintroduce infos
    "irc_nick_color" and "irc_nick_color_name", add support of
    server name (issue #194)
  * irc: add buffer for /list reply, add options
    irc.color.list_buffer_line_selected,
    irc.color.list_buffer_line_selected_bg,
    irc.look.list_buffer_sort,
    irc.look.list_buffer_scroll_horizontal,
    irc.look.new_list_position,
    irc.look.list_buffer_topic_strip_colors (issue #1972)
  * irc: display commands 716/717 in private buffer (if present)
    (issue #146)
  * irc: create default options irc.ctcp.* when file irc.conf
    is created (issue #1974)
  * irc: evaluate options irc.ctcp.* (issue #1974)
  * irc: build dynamically the list of CTCPs supported in reply
    to "CTCP CLIENTINFO" (issue #1974)
  * irc: remove Git revision and compilation date from CTCP
    VERSION reply (issue #1974)
  * irc: remove default CTCP replies FINGER and USERINFO
    (issue #1974)
  * irc, xfer: add support of passive DCC
    (issue #2004, issue #487)
  * script: rename parameters up/down/go to -up/-down/-go in
    command `/script`
  * script: allow jump to the last script with command
    `/script -go end`
  * script: allow commands `/script autoload`, `/script noautoload`,
    `/script toggleautoload` with scripts not present in the
    repository (issue #1980)
  * trigger: add options `-o`, `-ol`, `-i` and `-il` in command
    `/trigger list` (issue #1953)
  * core: fix zombie processes after fork (hook process or connect)
    (issue #1994)
  * core: fix generation of TOTP on Big Endian systems (issue #2021)
  * core: fix cursor position after `/plugin list -i` or `/plugin
    list -il`
  * core: display focus hashtable for debug even if no key is
    matching
  * fset: add local key bindings during the buffer creation
  * fset: remove extra spaces between min and max values when
    second format is used
  * fset: fix mouse actions when second format is used
  * fset: apply option fset.color.help_description (issue #1988)
  * irc: move value `-all` at the end of completions for command
    `/ignore del`
  * irc: fix memory leak when joining channels with keys
  * irc: fix unexpected message sent to server when part of the
    second line of an IRC command (issue #1992)
  * irc: fix display of country code in message 344 received as
    whois geo info (issue #1736)
  * irc: add missing "account-tag" in list of supported capabilities
  * irc: add channel in "autojoin" server option only when the
    channel is actually joined (issue #1990)
  * relay: synchronize nick modes with IRC client upon connection
    (issue #1984)
  * script: add local key bindings during the buffer creation
  * script: add parameters up/down/go in `/help script` and
    command completion
  * script: fix cursor position after `/script list -i` or
    `/script list -il`
  * script: fix buffer used by command `/script list -i|-il|-o|-ol`
  * xfer: display an error message when opening file for read or
    write fails (issue #2010)
  * core: add tests on GUI buffer functions
  * core: fix build error if CMake option ENABLE_NLS is turned to
    off or if required dependencies are not found (issue #2026)
  * core, logger, relay: make zstd dependency optional
    (issue #2024)
- changes from version 4.0.7
  * core: fix value of buffer variable "num_history" when the value
    defined in option weechat.history.max_commands is reached
  * core: remove incorrect warning when binding keys kbd:[F10] to
    kbd:[F20] (issue #2039)
  * core: fix memory leak when config version is invalid or not
    supported
  * core: fix crash when "config_version" is present in a
    configuration file without a value
  * core: display an error on startup if environment variable
    "HOME" is not set
  * irc: remove trailing "\r\n" in signals "irc_out" and
    "irc_outtags" when messages are queued
  * irc: fix target buffer of IRC message 337 (whois reply:
    "is hiding their idle time")
  * relay: close properly connection with the IRC client in case
    of server disconnection (issue #2038)
  * ruby: fix use of NULL variable when displaying exception
- changes from version 4.0.6
  * core: fix crash when a custom bar item name is already used
    by a default bar item (issue #2034)
  * core: fix generation of TOTP on Big Endian systems (issue #2021)
  * irc: move value `-all` at the end of completions for command
    `/ignore del`
  * irc: fix memory leak when joining channels with keys
  * core: fix build error if CMake option ENABLE_NLS is turned to
    off or if required dependencies are not found (issue #2026,
    issue #2031)
- changes from version 4.0.5
  * core: automatically backup config file read if it has an
    unsupported version (issue #2013)
  * core: display a message when a configuration file is updated
    to a newer version
  * python: make stub (weechat.pyi) compatible with Python 3.8
    and 3.9 (issue #2006)
  * irc: add option irc.look.open_pv_buffer_echo_msg to open
    private buffer on self message when capability echo-message
    is enabled (issue #2016)
  * irc: fix title of private buffers wrongly set to own address
    when capability echo-message is enabled (issue #2016)
  * irc: fix autojoin of channels when private buffers are opened
    (issue #2012)
  * irc: fix string comparison when CASEMAPPING is set to "ascii"
  * script: fix removal of script in system directory while trying
    to install a script (issue #2019)
  * script: fix autoload of multiple scripts at once with
    `/script autoload` (issue #2018)
  * script: fix crash when a `/script` command triggers another
    `/script` command (issue #923)
  * xfer: fix memory leak on plugin unload
  * irc: add tests on server functions
* Sun Sep 17 2023 malcolmlewis@opensuse.org
- Updated to version 4.0.4:
  * core: fix integer overflow when setting integer option with
    ++N or --N.
  * core: fix increment/decrement of options weechat.notify.*.
  * irc: add missing tags on multiline messages, (issue #1987).
  * irc: fix redirection of command /list when the reply doesn’t
    start with message 321 (start of /list).
  * irc: fix wrong time displayed for CTCP messages received from
    self nick, (issue #2000).
  * logger: remove trailing empty line in display of backlog,
    (issue #2002).
  * perl: fix display of non-ASCII chars after load of a script
    with Perl >= 5.38, (issue #1996).
  * script: adjust scroll after command /script go N.
- Changes from version 4.0.3:
  * core: fix input length and crash after delete of line,
    (issue #1989)
  * irc: fix display of self CTCP message containing bold
    attribute, (issue #1981).
  * irc: fix memory leak in IRC message parser.
  * irc: fix switch to channel manually joined when server option
    autojoin_dynamic is on and option
    irc.look.buffer_switch_autojoin is off, (issue #1982).
  * irc: fix display of outgoing notice with channel when
    capability "echo-message" is enabled, (issue #1991).
  * relay: fix display of IRC CTCP messages received from client,
    (issue #1986)
  * doc: display a warning if a locale is missing with fallback
    to English for auto-generated content, (issue #1985).
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.2:
  * https://weechat.org/files/doc/weechat/ChangeLog-4.0.2.html#v4.0.2
  * https://weechat.org/files/doc/weechat/ChangeLog-4.0.1.html#v4.0.1
  * https://weechat.org/files/doc/weechat/ChangeLog-4.0.0.html#v4.0.0
* Tue Mar 21 2023 Dirk Müller <dmueller@suse.com>
- update to 3.8:
  * https://blog.weechat.org/post/2023/01/08/Version-3.8
  * new Commands: /allbuf, /hotlist
  * add option weechat.look.chat_space_right
- drop weechat-ruby3.2.patch (upstream)
* Mon Mar  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add weechat-ruby3.2.patch: Fix build against Ruby 3.2.
- Add pkgconfig(libzstd) BuildRequires: fix linking of the
  binaries.
* Wed Nov  9 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 3.7.1:
  * core: add option -save in command /upgrade
  * core: add option weechat.look.highlight_disable_regex and buffer property "highlight_disable_regex"
  * core: sort filters by name
  * core: add key Alt+Backspace to delete previous word, change key Ctrl+w to delete previous word until whitespace
  * core: fix wrong terminal title on terminal resize, fix page scroll in bare display
  * api: rename function string_build_with_split_string to string_rebuild_split_string,
    add arguments "index_start" and "index_end"
  * irc: display SETNAME command in channels and private buffers,
    add options irc.color.message_setname and irc.look.smart_filter_setname
  * trigger: add elapsed time for trigger execution on monitor buffer when trigger debug is set,
    add option trigger.color.identifier, add variable ${tg_hook_type}
* Sun Jul 17 2022 Dirk Müller <dmueller@suse.com>
- update to 3.6:
  * core: add command `/item` to create custom bar items (issue #808)
  * core: add bar item "spacer" (issue #1700)
  * core: add case conversion in evaluation of expressions with `lower:string` and `upper:string` (issue #1778)
  * core: move detailed list of hooks from command `/plugin listfull` to `/debug hooks <plugin>`
  * core: allow to remove multiple filters at once with command `/filter del`
  * api: allow to catch multiple signals in functions hook_signal and hook_hsignal (issue #1780)
  * irc: rename option `save` to `apply` in command `/autojoin`
  * irc: add support of RPL_HELPSTART, RPL_HELPTXT and RPL_ENDOFHELP (messages 524, 704, 705, 706) (issue #1772)
  * php: add support of PHP 8.2 (issue #1787)
  * core: fix bad window size on startup with some terminals like https://github.com/kovidgoyal/kitty[kitty] (issue #1769)
  * api: run hook_print callback also on empty messages
  * buflist: fix memory leak when reading config and changing option buflist.look.sort
  * irc: remove channel from autojoin option when manually closing a buffer with `/buffer close` or `/close`
  * irc: fix add of channel to autojoin option when joining a channel with a buffer still opened
  * relay: fix save of channels in autojoin option when JOIN and PART commands are received from an IRC relay client (issue #1771)
  * trigger: add `${buffer.notify} > 0` in conditions of default trigger "beep"
  * trigger: fix completion of command `/trigger add` when there are spaces in the following arguments
  * trigger: fix memory leak in command `/trigger addinput`
* Sun Mar 27 2022 Dirk Müller <dmueller@suse.com>
- update to 3.5:
  * search in message tags when tags are displayed with "/debug tags"
  * add support of date and tags in messages displayed in buffers with free
    content, add function printf_y_date_tags
  * add command /autojoin, add IRC server option "autojoin_dynamic"
  * add IRC message tags in messages displayed
  * add "zstd" (Zstandard) compression in relay weechat protocol, remove option
    "compression" from "init" command, rename option
    relay.network.compression_level to relay.network.compression
  * add trigger variables "${tg_tag_irc_xxx}" containing IRC message tags
  * many bugs fixed.
- drop 0001-ruby-add-detection-of-Ruby-3.1.patch (upstream)
* Mon Mar 14 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.4.1:
  * core: set again TLS verification functions after options
    weechat.network.gnutls_ca_system and
    weechat.network.gnutls_ca_user are changed (boo#1197083)
* Fri Feb 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * 0001-ruby-add-detection-of-Ruby-3.1.patch
* Mon Dec 20 2021 Dirk Müller <dmueller@suse.com>
- update to 3.4:
  * core: add support of static arrays in hdata
  * core: add command /toggle
  * api: add parameters pointers, extra_vars and options in function hdata_search
  * api: add user variables in evaluation of expressions with "define:name,value"
  * api: add IRC message parameters "param1" to "paramN" and "num_params" in
    output of irc_message_parse
  * irc: allow quotes around IRC message in command /server fakerecv
  * trigger: hide key and password in command "/msg nickserv setpass nick key password"
  * trigger: add support of option "-server" when hiding passwords in command
    /msg nickserv register
  * core: fix memory leak in evaluated expression "split:number,seps,flags,xxx" when
    multiple "strip_items" are given
  * core: fix random integer number with large range in evaluation of expressions on GNU/Hurd
  * core: fix access to integer/long/time arrays in hdata
  * api: fix search of option when the section is not given in functions
    config_search_option and config_search_section_option
  * irc: fix join of channels with long name (issue #1717)
  * irc: fix parsing of parameters in all IRC messages (issue #1666)
  * irc: fix parsing of CAP message when there is no prefix (issue #1707)
  * irc: fix parsing of TAGMSG message when there is a colon before the channel
  * doc: remove tester's guide
  * doc: add dark theme (automatic, following browser/desktop settings)
  * doc: make build reproducible
  * doc: disable web fonts
  * doc: switch from prettify to pygments for syntax highlighting
  * core: add build with CMake and Ninja in CI
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 3.3:
  * core: change key kbd:[Alt+h] to kbd:[Alt+h], kbd:[Alt+c]
  * core: add options "hotlist_remove_buffer", "hotlist_restore_buffer" and "hotlist_restore_all"
  * core: add option "certs" in command /debug
  * core: add options "-o", "-ol", "-i" and "-il" in command "/plugin list"
  * api: add split of string and shell arguments in evaluation of expressions
    with "split:number,seps,flags,xxx" and "split_shell:number,xxx"
  * api: add `${re:repl_index}` to get the index of replacement in function
    string_eval_expression
  * api: add random integer number in evaluation of expressions with "random:min,max"
  * api: add function string_cut
  * api: add function file_copy
  * api: remember insertion order in hashtables
  * api: add keys/values with tags in output of irc_message_parse_to_hashtable
  * irc: add option "-parted" in command /allchan
  * irc: allow signals "irc_raw_in" and "irc_in" to eat messages
  * irc: implement IRCv3.2 SASL authentication, add command /auth, reconnect by
    default to the server in case of SASL authentication failure
  * irc: add support of capability "message-tags" and TAGMSG messages
  * irc: enable all capabilities by default (if supported by server and WeeChat),
    change default value of option irc.server_default.capabilities to "*"
  * irc: add options irc.look.display_account_message and irc.look.display_extended_join
  * irc: add command /setname, add support of message and capability "setname"
  * irc: always set realname in nicks even when extended-join capability is not enabled
  * irc: add support of FAIL/WARN/NOTE messages
  * irc: drop support of DH-BLOWFISH and DH-AES SASL mechanisms
  * typing: new plugin "typing": display users currently writing messages on
    IRC channel/private buffers
  * core: fix decoding of attributes in basic ANSI colors
  * api: fix function string_match with joker in the string if multiple words
    matched in input string
  * irc: fix send of empty JOIN when connecting to a server with only parted channels
  * irc: fix SASL authentication when AUTHENTICATE message is received with a server name
  * irc: remove unneeded message about Diffie-Hellman shared secret exchange during SSL connection to server
  * irc: escape/unescape IRC message tags values
  * irc: set notify level to "private" for received WALLOPS
  * script: fix move of installed script on another filesystem
  * core: switch to PHP 8.0 in CI
  * core: add build on macOS in CI
  * core: fix build on macOS (issue #1662)
  * lua: add detection of Lua 5.4
  * php: add support of PHP 8.0 and 8.1 (issue #1599, issue #1668)
* Sun Jul  4 2021 Maximilian Trummer <opensuse@trummer.xyz>
- update to 3.2
- main changes:
  * use XDG directories by default (config, data, cache, runtime)
  * add support of IRC SASL mechanisms
    SCRAM-SHA-1, SCRAM-SHA-256 and SCRAM-SHA-512
  * automatically load system certificates
    without giving a hardcoded path to the file with certificates
  * add options to customize commands executed on system signals received
    (SIGHUP, SIGQUIT, SIGTERM, SIGUSR1, SIGUSR2)
  * add bar item "tls_version" and buflist format
  * add signals "cursor_start" and "cursor_end"
  * add function crypto_hmac in API
  * add translated string in evaluation of expressions with "translate:xxx"
  * add info "weechat_daemon"
  * add Python stub for WeeChat API
  * add variables "${tg_shell_argc}" and "${tg_shell_argvN}"
    in command trigger evaluated strings
  * many bugs fixed.
- for all changes, please visit:
  https://weechat.org/files/changelog/ChangeLog-3.2.html
* Sun Mar  7 2021 Maximilian Trummer <opensuse@trummer.xyz>
- update to 3.1
- New features
  * core: add options weechat.look.hotlist_update_on_buffer_switch
    and weechat.look.read_marker_update_on_buffer_switch (issue #992, issue #993)
  * core: add option sec.crypt.passphrase_command to read passphrase from an
    external program on startup, remove option sec.crypt.passphrase_file (issue #141)
  * core: improve debug in command /eval: display more verbose debug
    with two "-d", add indentation and colors
  * core: add options "setvar" and "delvar" in command /buffer,
    rename option "localvar" to "listvar"
  * core: add buffer local variable "completion_default_template" (evaluated)
    to override the value of option "weechat.completion.default_template" (issue #1600)
  * core: add option "recreate" in command /filter
  * core: add raw string in evaluation of expressions with "raw:xxx" (issue #1611)
  * core: add evaluation of conditions in evaluation of expressions
    with "eval_cond:xxx" (issue #1582)
  * api: add info_hashtable "secured_data"
  * irc: add info "irc_is_message_ignored"
  * irc: add server option "default_chantypes",
    used when the server does not send them in message 005 (issue #1610)
  * trigger: add variable "${tg_trigger_name}" in command trigger evaluated strings (issue #1580)
- Bug fixes
  * core: fix quoted line in cursor mode (issue #1602)
  * core: fix wrong size of the new window after vertical split (issue #1612)
  * core: do not remove quotes in arguments of command /eval
    as they can be part of the evaluated expression/condition (issue #1601)
  * core: display an error when the buffer is not found with command /command -buffer
  * buflist: add option buflist.look.use_items to speed up display of buflist (issue #1613)
  * irc: add bar item "irc_nick_prefix"
  * irc: fix separator between nick and host in bar item "irc_nick_host"
  * irc: fix completion of commands /halfop and /dehalfop
- Documentation
  * do not build weechat-headless man page if headless binary is disabled (issue #1607)
* Tue Feb  2 2021 Dirk Müller <dmueller@suse.com>
- update to 3.0.1:
  * exec: fix search of command by identifier
  * spell: fix refresh of bar item "spell_suggest" when the input becomes empty (issue #1586)
  * spell: fix crash with IRC color codes in command line (issue #1589)
* Wed Nov 11 2020 Maximilian Trummer <opensuse@trummer.xyz>
- update to 3.0
- New features
  * api: add optional list of colors in infos "nick_color" and "nick_color_name" (issue #1565)
  * api: add argument "bytes" in function string_dyn_concat
  * api: add function string_color_code_size (issue #1547)
  * exec: add option "-oerr" to send stderr to buffer (now disabled by default) (issue #1566)
  * fset: add option fset.look.auto_refresh (issue #1553)
  * irc: add pointer to irc_nick in focus of bar item "buffer_nicklist" (issue #1535, issue #1538)
  * irc: allow to send text on buffers with commands /allchan, /allpv and /allserv
  * irc: evaluate command executed by commands /allchan, /allpv and /allserv (issue #1536)
  * script: add option script.scripts.download_enabled (issue #1548)
  * trigger: add variable "tg_argc" in data set by command trigger (issue #1576)
  * trigger: add variable "tg_trigger_name" in data set by all triggers (issue #1567, issue #1568)
- Bug fixes
  * core: set "notify_level" to 3 if there is a highlight in the line (issue #1529)
  * core: do not add line with highlight and tag "notify_none" to hotlist (issue #1529)
  * irc: remove SASL timeout message displayed by error
    after successful SASL authentication (issue #1515)
  * irc: send all channels in a single JOIN command when reconnecting to the server (issue #1551)
  * script: do not automatically download list of scripts on startup
    if the file is too old (issue #1548)
  * spell: properly skip WeeChat and IRC color codes when checking words in input (issue #1547)
  * trigger: fix recursive calls to triggers using regex (issue #1546)
  * trigger: add ${tg_tags} !!- ,notify_none, in conditions of default trigger "beep" (issue #1529)
- Tests
  * core: add tests on GUI line functions
- Build
  * core: disable debug by default in autotools build
  * tests: fix compilation with CppUTest ≥ 4.0
* Mon Jul 20 2020 Maximilian Trummer <opensuse@trummer.xyz>
- new .desktop file from weechat sources
- update to 2.9
- New features
  * core: add bar option "color_bg_inactive": color for window bars
    in inactive window (issue #732)
  * core: add Alacritty title escape sequence support (issue #1517)
  * core: display notify level for current buffer
    with command /buffer notify (issue #1505)
  * core: count only visible nicks in bar item "buffer_nicklist_count",
    add bar items "buffer_nicklist_count_groups" and "buffer_nicklist_count_all"
    (issue #1506)
  * core: set default size for input bar to 0 (automatic) (issue #1498)
  * core: add default key Alt+Enter to insert a newline (issue #1498)
  * core: add flag "input_multiline" in buffer (issue #984, issue #1063)
  * core: add a scalable WeeChat logo (SVG) (issue #1454, issue #1456)
  * core: add base 16/32/64 encoding/decoding in evaluation of expressions
    with "base_encode:base,xxx" and "base_decode:base,xxx"
  * core: add case sensitive wildcard matching comparison operator (==* and !!*)
    and case sensitive/insensitive include comparison operators (==-, !!-, =-, !-)
    in evaluation of expressions
  * core: add default key Alt+Shift+N to toggle nicklist bar
  * core: add command line option "--stdout" in weechat-headless binary
    to log to stdout rather than ~/.weechat/weechat.log (issue #1475, issue #1477)
  * core: reload configuration files on SIGHUP (issue #1476)
  * api: add pointer "_bar_window" in hashtable sent to hook focus callback (issue #1450)
  * api: add info_hashtable "focus_info" (issue #1245, issue #1257)
  * api: rename function hook_completion_get_string to completion_get_string
    and hook_completion_list_add to completion_list_add
  * api: add functions completion_new, completion_search and completion_free
  * api: add hdata "completion_word"
  * buflist: add default key Alt+Shift+B to toggle buflist
  * buflist: add options enable/disable/toggle in command /buflist
  * buflist: evaluate option buflist.look.sort so that sort can be customized
    for each of the three buflist bar items (issue #1465)
  * irc: add support of UTF8MAPPING (issue #1528)
  * irc: display account messages in buffers (issue #1250)
  * python: add WeeChat sharedir python directory to PYTHONPATH (issue #1537)
  * relay: increase default limits for IRC backlog options
  * relay: add command "handshake" in weechat relay protocol and nonce
    to prevent replay attacks, add options relay.network.password_hash_algo,
    relay.network.password_hash_iterations, relay.network.nonce_size (issue #1474)
  * relay: add command "completion" in weechat relay protocol
    to perform a completion on a string at a given position (issue #1484)
  * relay: add option relay.network.auth_timeout
  * relay: update default colors for client status
  * relay: add status "waiting_auth" in irc and weechat protocols (issue #1358)
  * trigger: evaluate arguments of command when the trigger is created (issue #1472)
- Bug fixes
  * core: fix command /window scroll_beyond_end when buffer has fewer lines
    than chat height (issue #1509)
  * core: force buffer property "time_for_each_line" to 0 for buffers
    with free content (issue #1485)
  * core: don’t collapse consecutive newlines in lines displayed
    before the first buffer is created
  * core: don’t remove consecutive newlines when pasting text (issue #1500)
  * core: don’t collapse consecutive newlines in bar content (issue #1500)
  * core: fix WEECHAT_SHAREDIR with CMake build (issue #1461)
  * core: fix memory leak in calculation of expression on FreeBSD (issue #1469)
  * core: fix resize of a bar when its size is 0 (automatic) (issue #1470)
  * api: fix use of pointer after free in function key_unbind
  * api: replace plugin and buffer name by buffer pointer in argument "modifier_data"
    sent to weechat_print modifier callback (issue #42)
  * buflist: add "window" pointer in bar item evaluation only if it’s not NULL
    (if bar type is "window")
  * exec: fix use of same task id for different tasks (issue #1491)
  * fifo: fix errors when writing in the FIFO pipe (issue #713)
  * guile: enable again /guile eval (issue #1514)
  * irc: use new default chantypes "#&" when the server does not send it
  * irc: add support of optional server in info "irc_is_nick",
    fix check of nick using UTF8MAPPING isupport value (issue #1528)
  * irc: fix add of ignore with flags in regex, display full ignore mask
    in list of ignores (issue #1518)
  * irc: do not remove spaces at the end of users messages received (issue #1513)
  * irc: fix realname delimiter color in WHO/WHOX response (issue #1497)
  * irc: reuse a buffer with wrong type "channel"
    when a private message is received (issue #869)
  * python: fix crash when invalid UTF-8 string is in a WeeChat hashtable
    converted to a Python dict (issue #1463)
  * relay: add missing field "notify_level" in message "_buffer_line_added" (issue #1529)
  * relay: fix slow send of data to clients when SSL is enabled
  * trigger: only return trigger’s return code
    when condition evaluates to true (issue #592)
  * trigger: fix truncated trigger command with commands /trigger input|output|recreate
  * trigger: do not hide values of options with /set command in cmd_pass trigger
- Documentation
  * add includes directory
  * merge 53 auto-generated files into 11 files
  * fix broken literal blocks in Japanese docs with Firefox (issue #1466)
- Tests
  * core: add CI with GitHub Actions, move codecov.io upload to GitHub Actions
  * core: switch to Ubuntu Bionic on Travis CI, use pylint3 to lint Python scripts
  * core: run tests on plugins only if the plugins are enabled and compiled
  * irc: add tests on IRC color and channel functions
- Build
  * javascript: disable build by default and remove Debian packaging
    of JavaScript plugin (issue #360)
  * core: make GnuTLS a required dependency
  * core: fix build with CMake 3.17.0
  * core: fix build with cygport on Cygwin
* Sun Mar 29 2020 Maximilian Trummer <opensuse@trummer.xyz>
- update to 2.8
- New features
  * core: add variable "old_full_name" in buffer,
    set during buffer renaming (issue #1428)
  * core: add debug option "-d" in command /eval (issue #1434)
  * api: add functions crypto_hash and crypto_hash_pbkdf2
  * api: add info "auto_connect" (issue #1453)
  * api: add info "weechat_headless" (issue #1433)
  * buflist: add pointer "window" in bar item evaluation
  * irc: add support of fake servers (no I/O, for testing purposes)
  * relay: accept hash of password in init command of weechat protocol
    with option "password_hash" (PBKDF2, SHA256, SHA512)
  * relay: reject client with weechat protocol if password or totp is
    received in init command but not set in WeeChat (issue #1435)
- Bug fixes
  * core: fix memory leak in completion
  * core: flush stdout/stderr before forking
    in hook_process function (issue #1441)
  * core: fix evaluation of condition with nested "if" (issue #1434)
  * irc: split AUTHENTICATE message in 400-byte chunks (issue #1459)
  * irc: copy temporary server flag in command /server copy
  * irc: add nick changes in the hotlist (except self nick change)
  * irc: case-insensitive comparison on incoming CTCP command,
    force upper case on CTCP replies (issue #1439)
  * irc: fix memory leak when the channel topic is changed
  * logger: fix crash when logging is disabled on a buffer
    and the log file was deleted in the meanwhile, when
    option logger.file.info_lines is on (issue #1444)
  * php: fix crash when loading script with PHP 7.4 (issue #1452)
  * relay: update buffers synchronization
    when buffers are renamed (issue #1428)
  * script: fix memory leak in read of script repository file
    if it has invalid content
  * script: fix unexpected display of scripts list in buffer
    with command /script list -i
  * xfer: send signal "xfer_ended" after the received file
    has been renamed (issue #1438)
- Tests
  * scripts: fix generation of test scripts with Python 3.8
  * unit: add tests on IRC protocol functions and callbacks
  * unit: add tests on function secure_derive_key
  * unit: add tests on functions util_get_time_diff and util_file_get_content
- Build
  * core: fix Cygwin build
  * guile: add detection of Guile 3.0.0 (issue #1442)
  * irc: fix build with GnuTLS < 3.1.0 (issue #1431)
  * php: add detection of PHP 7.4
  * ruby: add detection of Ruby 2.7 (issue #1455)
* Thu Feb 20 2020 Maximilian Trummer <opensuse@trummer.xyz>
- update to 2.7.1
- Bug fixes
  * irc: fix crash when receiving a malformed message 352 (who)
  * irc: fix crash when a new message 005 is received with longer nick prefixes
  * irc: fix crash when receiving a malformed message 324 (channel mode) (CVE-2020-8955)
- removed CVE-2020-8955.patch: fixed upstream
* Mon Feb 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- fix boo#1163889 - CVE-2020-8955 , add patch CVE-2020-8955.patch
* Fri Jan 31 2020 Maximilian Trummer <opensuse@trummer.xyz>
- update to 2.7
- New features
  * core: add option weechat.look.nick_color_hash_salt to shuffle nick colors (issue #635)
  * core: add different icons sizes (16x16 to 512x512) (issue #1347)
  * core: add file weechat.desktop
  * core: add reverse of string for screen in evaluation of expressions with "revscr:"
  * core: add length of string (number of chars and on screen) in evaluation of expressions with "length:xxx" and "lengthscr:xxx"
  * core: add calculation of expression in evaluation of expressions with "calc:xxx" (issue #997)
  * core: add optional default path (evaluated) in completion "filename"
  * core: add support of modifiers in evaluation of expressions with "modifier:name,data,string"
  * api: add modifier "color_encode_ansi" (issue #528)
  * api: add modifier "eval_path_home"
  * irc: add filters on raw buffer (issue #1000)
  * irc: add option irc.look.display_pv_warning_address to display a warning in private buffer if the remote nick address has changed (issue #892)
  * irc: add server option "ssl_password" (issue #115, issue #1416)
  * irc: add "user" in output of irc_message_parse (issue #136)
  * irc: add options irc.color.message_kick and irc.color.reason_kick (issue #683, issue #684)
  * logger: add option logger.file.color_lines (issue #528, issue #621)
  * script: add options "-ol" and "-il" in command "/script list" to send translated string with list of scripts loaded, display "No scripts loaded" if no scripts are loaded
  * xfer: add option xfer.file.download_temporary_suffix with default value ".part" (issue #1237)
- Bug fixes
  * core: set buffer name, short name and title only if the value has changed
  * core: fix scrolling up in bare mode when switched to bare mode at the top of the buffer (issue #899, issue #978)
  * core: optimize load of configuration files
  * core: fix window separators not respecting window splits (issue #630)
  * core: fix cursor mode info when prefix_align is none and with words split across lines (issue #610, issue #617, issue #619)
  * core: add support of reverse video in ANSI color codes
  * core: fixed segfault during excessive evaluation in function string_repeat (issue #1400)
  * buflist: fix extra spaces between buffers when conditions are used to hide buffers (regression introduced in version 2.6) (issue #1403)
  * irc: do not automatically open a channel with name "0" (issue #1429)
  * irc: remove option irc.network.channel_encode, add server option "charset_message" to control which part of the IRC message is decoded/encoded to the target charset (issue #832)
  * irc: use path from option xfer.file.upload_path to complete filename in command "/dcc send" (issue #60)
  * logger: fix write in log file if it has been deleted or renamed (issue #123)
  * python: send "bytes" instead of "str" to callbacks in Python 3 when the string is not UTF-8 valid (issue #1389)
  * relay: send message "_buffer_title_changed" to clients only when the title is changed
  * xfer: fix memory leak when a xfer is freed and when the plugin is unloaded
- Tests
  * unit: add tests on GUI color functions
- Build
  * core: fix build on Haiku (issue #1420)
  * core: fix build on Alpine
  * core: remove file FindTCL.cmake
  * core: display an error on missing dependency in CMake (issue #916, issue #956)
  * debian: disable Javascript plugin on Debian Sid and Ubuntu Eoan
  * debian: build with Guile 2.2
  * guile: add support of Guile 2.2, disable /guile eval (issue #1098)
  * python: add detection of Python 3.8
* Fri Sep 13 2019 Maximilian Trummer <opensuse@trummer.xyz>
- update to 2.6
  * use Python 3 by default
  * add support of 32767 color pairs
  * add option "close" in command /window
  * add infos "term_colors" and "term_color_pairs"
  * add infolist "buflist" with list of buffer pointers
  * evaluate option exec.command.shell, change default value to "${env:SHELL}"
  * add filters "h=xxx" and "he=xxx" to filter options by description in fset buffer (translated or in English)
  * make command char optional in server option "command"
  * remove default aliases /ame and /amsg
  * many bugs fixed.
* Mon Sep  2 2019 Adriaan Struys <amjsfw@gmail.com>
- add obsolete for weechat-aspell
* Mon Sep  2 2019 Adriaan Struys <amjsfw@gmail.com>
- update to 2.5
  * the "aspell" plugin has been renamed to "spell", a more generic term, because it supports aspell and also enchant
  * add support of UNIX socket
  * fix memory leaks
  * more bugfixes and new options
- change subpackage 'weechat-aspell' to 'weechat-spell' to reflect plugin namechange
* Mon Feb 25 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 2.4
  * add command line option "-t" (or "--temp-dir")
  * add support of Time-based One-Time Password (TOTP)
  * add option exec.command.shell to customize the shell used with /exec -sh
  * add support of close frame in websocket connection
* Mon Nov 26 2018 jbrielmaier@suse.de
- remove guile bindings as they are not compatible with guile-2.2
  Upstream work for guile-2.2:
  https://github.com/weechat/weechat/issues/1098
  part of boo#1117121
- obsoletes weechat-guile
* Tue Oct 23 2018 Ondřej Súkup <mimi.vx@gmail.com>
- update to version 2.3
  * add hook "line"
  * add option "-P" (or "--plugins") to customize the plugins to load at startup
  * allow multiple options "-r" ("--run-command") in command line arguments
  * allow allow partial buffer name and multiple arguments in command /buffer close
  * allow specifying buffer number/name for /buffer localvar
  * allow creation of temporary variables with the regex in trigger plugin
  * add real IP in client description in relay plugin
  * add repeat of string in evaluation of expressions with "repeat:count,string"
  * many bugs fixed.
* Tue Jul 17 2018 mimi.vx@gmail.com
- update to 2.2
  * add support of list options in curl
  * allow merge of buffers by name in command /buffer
  * add reverse of string in evaluation of expressions with "rev:"
  * add indexed ban list and completion for /unban and /unquiet (IRC plugin)
  * add support for IRCv3.2 Client Capability Negotiation
  * add support for IRCv3.2 invite-notify
  * add support for IRCv3.2 chghost, add options irc.look.smart_filter_chghost
    and irc.color.message_chghost
  * add option xfer.network.send_ack
  * add support of Python 3.7
  * fix memory leaks scripting plugins
  * many bugs fixed.
* Mon Mar 19 2018 jengelh@inai.de
- Ensure neutrality of description.
- Use -exec over xargs.
* Mon Mar 19 2018 mimi.vx@gmail.com
- update to 2.1
- build python plugin against python3
  * core: add binary weechat-headless to run WeeChat without interface, with
  optional daemon mode (command line option "--daemon")
  * core: add options "-newbuffer", "-free" and "-switch" in command /print
  * core: add option "-y" in command /print, add support of buffers with free content
  * core: add option "add" in command /buffer
  * core: add option weechat.completion.partial_completion_templates to force
    partial completion on specific templates
  * api: add hashtable with variables in plugin structure
  * irc: add server option "split_msg_max_length"
  * logger: add option logger.file.fsync
  * logger: add option logger.look.backlog_conditions)
  * scripts: add configuration file for each script plugin
  * scripts: add "eval" option in script commands and info "xxx_eval"
  * scripts: add infos "xxx_interpreter" and "xxx_version" in script plugins
  * scripts: add option "version" in script commands
  * api: add time in info "date" (WeeChat compilation date/time)
  * irc: allow ${irc_server.xxx} and ${server} in server evaluated options
  * script: change default value of option script.look.sort from "p,n" to "i,p,n"
  * scripts: display the script name in stdout/stderr output from scripts
  * core: fix regression on execution of hook_print callbacks
* Thu Dec 21 2017 mimi.vx@gmail.com
- update to 2.0.1
  * python: fix arguments status/gnutls_rc/sock in hook_connect() callback
  * python: fix argument fd in hook_fd() callback
  * core: add flag "input_get_empty" in buffer
  * core: add signals "buffer_filters_enabled" and "buffer_filters_disabled"
  * core: support loading of plugins from path in environment
    variable "WEECHAT_EXTRA_LIBDIR"
  * alias: add infolist "alias_default" (list of default aliases)
  * buflist: add two new bar items ("buflist2" and "buflist3") using the same
    format configuration options
  * buflist: add option buflist.look.add_newline
  * fset: new plugin "fset" (fast set of WeeChat and plugins options)
  * core: make value optional in command /buffer set
  * core: allow floating point and hexadecimal numbers in comparison of evaluated values
  * core: add option weechat.look.save_config_with_fsync
  * api: add support of prefix "quiet:" in function key_unbind() to quietly remove keys
  * api: add argument "recurse_subdirs" in function exec_on_files()
  * script: add local variable "filter" in the script buffer
  * core: do not change the chat prefix size when a filtered line is added
  * core: fix display of nicks in nicklist when they are in a group with sub-groups
  * core, plugins: check return code of strftime function
  * core: fix cast of time_t (to "long long" instead of "long")
  * core: call the config hook when options are renamed or removed
  * api: change type of arguments status/gnutls_rc/sock in hook_connect() callback
    from string to integer (in scripts)
  * api: change type of argument fd in hook_fd() callback from
    string to integer (in scripts)
  * buflist: remove recursive evaluation of extra variables
  * guile: return integer (0/1) instead of boolean in API functions
  * guile: fix return value of static strings in API functions
  * irc: do not clear nicklist when joining an already joined channel if
    the option irc.look.buffer_open_before_join is on
  * irc: fix CTCP PING reply when the option irc.ctcp.ping is set to non-empty value
  * lua: fix boolean return value (as integer) in API functions
  * relay: fix parsing of CAP command without arguments in irc protocol, send ACK
    only if all capabilities received are OK and NAK otherwise
  * core: fix build with ncurses and separate tinfo
* Mon Sep 25 2017 tchvatal@suse.com
- Version update to 1.9.1:
  * Security update to fix CVE-2017-14727 bsc#1060140
* Sun Jun 25 2017 mimi.vx@gmail.com
- update to 1.9
  * improve speed of nicklist bar item callback
  * add auto scroll of buflist bar with new option buflist.look.auto_scroll
  * add option buflist.format.name
  * add variables ${format_name}, ${current_buffer} and ${merged}@@ in buflist
  * display a warning in buflist when the script buffers.pl is loaded
  * add server/channel pointers in trigger IRC callbacks
  * add API functions config_option_get_string and hdata_compare
  * fix bind of Space key
  * many bugs fixed.
  * buflist.format.name
  * buflist.look.auto_scroll
  * F1/F2: scroll buflist bar
* Mon May 15 2017 mimi.vx@gmail.com
- update to 1.8
  * add option weechat.completion.nick_case_sensitive
  * add wilcard matching operator, cut of string and ternary operator
    in evaluation of expressions
  * add resize of window parents with /window resize [h/v]size
  * add plugin "buflist" (bar with list of buffers)
  * add arraylist and dynamic string functions in API
  * add option "open" in command /server
  * add signal "irc_server_lag_changed" and store the lag
    in the server buffer (local variable)
  * add aspell options to control delimiters in suggestions
  * add option "-include" in commands /allchan, /allpv and /allserv
  * many bugs fixed.
* Sat Apr 22 2017 mimi.vx@gmail.com
- Update to version 1.7.1
  * irc: fix parsing of DCC filename CVE-2017-8073 (boo#1036467)
* Sun Jan 15 2017 mimi.vx@gmail.com
- Update to version 1.7
  * New features
    + core: add option weechat.look.align_multiline_words
    + core: add optional command prefix in completion templates "commands",
  "plugins_commands" and "weechat_commands"
    + core: add optional arguments in completion template, sent to the callback
    + core: add option "time" in command /debug
    + api: add info "uptime" (WeeChat uptime)
    + api: add info "pid" (WeeChat PID)
    + fifo: add file fifo.conf and option fifo.file.path to customize
  FIFO pipe path/filename
    + irc: add server option "usermode"
    + irc: add tag "self_msg" on self messages
  * Improvements
    + core, xfer: display more information on fork errors
    + core: add a slash before commands completed in arguments of /command,
  /debug time, /key bind, /key bindctxt, /mute, /repeat, /wait
    + core: add a warning in header of configuration files to not edit by hand
    + alias: add a slash before commands completed in arguments of /alias
    + exec: add option "-oc" in command /exec to execute commands in process
  output, don’t execute commands by default with "-o"
    + irc: evaluate content of server option "ssl_fingerprint"
    + irc: change default value of option irc.network.lag_reconnect from 0 to 300
    + trigger: do not hide email in command "/msg nickserv register password email"
  * Bug fixes
    + core: fix deadlock when quitting after a signal SIGHUP/SIGQUIT/SIGTERM
  is received
    + core: fix display of empty lines in search mode
    + api: fix crash in function string_expand_home() when the HOME environment
  variable is not set
    + exec: fix memory leak in display of process output
    + irc: fix option "-temp" in command /server
    + irc: fix close of server channels which are waiting for the JOIN when
  the server buffer is closed
    + irc: fix buffer switching on manual join for forwarded channels
    + irc: add missing tags on CTCP message sent
    + lua: fix integers returned in Lua >= 5.3
    + relay: make HTTP headers case-insensitive for WebSocket connections
    + relay: set status to "authentication failed" and close immediately
  connection in case of authentication failure in weechat and irc protocols
    + script: reload a script after upgrade only if it was loaded, set autoload
  only if the script was auto-loaded
* Sun Oct  2 2016 mimi.vx@gmail.com
- update to version 1.6
- removed weechat-doc subpackage, ( BuildRequires dep missing )
  * New features:
  + core: add optional argument "lowest", "highest" or level mask in command
    /input hotlist_clear
  + core: add option "cycle" in command /buffer
  + api: add "extra" argument to evaluate extra variables in function
    string_eval_expression()
  + relay: add option relay.network.allow_empty_password
  + trigger: add support for one-time triggers
  Improvements
  + core, irc, xfer: display more information in memory allocation errors
  + api: remove functions printf_date() and printf_tags()
  + irc: rename server options "default_msg_{kick|part|quit}" to
    "msg_{kick|part|quit}", evaluate them
  + relay: allow escape of comma in command "init" (weechat protocol)
  Bug fixes
  + core, irc, xfer: refresh domain name and name server addresses before
    connection to servers (fix connection to servers after suspend mode)
  + api: fix return of function string_match() when there are multiple masks
    in the string
  + api: fix crash in function network_connect_to() if address is NULL
  + api: fix connection to servers with hook_connect() on Windows 10 with
    Windows subsystem for Linux
  + api: fix crash in function string_split_command() when the separator
    is not a semicolon
  + irc: fix socket leak in connection to server
  + irc: fix display of service notice mask (message 008)
  + irc: fix NULL pointer dereference in 734 command callback
  + relay: return an empty hdata when the requested hdata or pointer is not found
  + xfer: fix crash on DCC send if option xfer.file.auto_accept_nicks is set
  Documentation
  + switch to asciidoctor to build docs and man page
* Tue Jun 14 2016 mimi.vx@gmail.com
- fix typo in %%if conditional
* Sun May 15 2016 mimi.vx@gmail.com
- update to 1.5
  * New features:
  + core: add Portuguese translations
  + core: change default value of option weechat.look.nick_color_hash to "djb2"
  + core: move nick coloring from irc plugin to core, move options
  irc.look.nick_color_force, irc.look.nick_color_hash and
  irc.look.nick_color_stop_chars to core, add info "nick_color" and
  "nick_color_name", deprecate info "irc_nick_color" and "irc_color_name"
  + core: move irc bar item "away" to core, move options irc.look.item_away_message
  and irc.color.item_away to core
  + api: add support of functions in hook_process
  + api: add pointer in callbacks used in scripting API
  + irc: add option irc.network.sasl_fail_unavailable
  + irc: add multiple targets and support of "-server" in command /ctcp
  + ruby: add detection of Ruby 2.3
  + trigger: add "recover" in default triggers cmd_pass/msg_auth, and "regain"
  in default trigger "msg_auth"
  * Bugs fixed:
  + core: fix nick coloring when stop chars and a forced color are used: first
  remove chars then look for forced color
  + core: check that pointers received in arguments are not NULL in buffers
  and windows functions
  + core: fix truncation of buffer names in hotlist
  + core: fix update of window title under Tmux
  + core: fix detection of Python shared libraries
  + api: fix number of arguments returned by function string_split() when
  keep_eol is 2 and the string ends with separators
  + irc: fix first message displayed in raw buffer when the message is modified
  by a modifier
  + irc: add missing completion "*" for target in command /msg
  + irc: fix /msg command with multiple targets including "*"
  + lua: fix crash when a lua function doesn’t return a value and a string
  was expected
  + relay: do not execute any command received in a PRIVMSG message from
  an irc relay client
  + relay: fix the max number of clients connected on a port, allow value
  0 for "no limit"
  + relay: fix decoding of multiple frames in a single websocket message, send
  PONG on PING received in a websocket frame
  + relay: fix command "input" received from clients with only spaces in content
  of message (weechat protocol)
  + script: force refresh of scripts buffer after download of scripts list
  + xfer: fix DCC file received when the terminal is resized
* Sun Mar 20 2016 bwiedemann@suse.com
- Fix build-compare
- include .changes file as Source so that .src.rpm can be rebuilt
* Thu Feb 18 2016 mimi.vx@gmail.com
- fix sle12 conditional
* Mon Jan 11 2016 mimi.vx@gmail.com
- add weechat.keyring and verify source tarball by gpg
* Sun Jan 10 2016 mimi.vx@gmail.com
- Version bump to 1.4
  + New features:
  * core: add a parent name in options, display inherited values if null in /set
  output, add option weechat.color.chat_value_null
  * core: add tag "term_warning" in warnings about wrong $TERM on startup
  * core: add option weechat.look.paste_auto_add_newline
  * core: display a more explicit error when a filter fails to be added
  * api: add function string_hex_dump()
  * api: add argument "length" in function utf8_is_valid()
  * alias: display completion in /alias list
  * fifo: add /fifo command
  * irc: evaluate content of server option "addresses"
  * irc: move option irc.network.alternate_nick into servers
  (irc.server.xxx.nicks_alternate)
  * irc: track real names using extended-join and WHO
  * irc: add support of SNI (Server Name Indication) in SSL connection
  to IRC server
  * irc: use current channel and current server channels first in completions
  "irc_server_channels" and "irc_channels"
  * irc: add support of "cap-notify" capability
  * irc: add command /cap
  * irc: add hex dump of messages in raw buffer when debug is enabled for irc
  plugin (level 2 or more)
  * logger: display system error when the log file can not be written
  * relay: add option relay.irc.backlog_since_last_message
  * script: add completion with languages and extensions, support search by
  language/extension in /script search
  * script: add option script.scripts.download_timeout
  * doc: add Czech man page and quickstart guide
  * tests: check if all plugins are loaded
  + Bugs fixed:
  * core: fix execution of empty command name ("/" and "/ " are not valid
  commands)
  * core: fix memory leak when using multiple "-d" or "-r" in command line
  arguments
  * core: don’t complain any more about "tmux" and "tmux-256color" $TERM values
  when WeeChat is running under tmux
  * core: fix truncated messages after a word with a length of zero on screen
  (for example a zero width space: U+200B)
  * api: fix handle of invalid escape in function string_convert_escaped_chars()
  * alias: do not allow slashes and spaces in alias name
  * irc: fix channel forwarding when option
  irc.look.buffer_open_before_{autojoin|join} is on
  * irc: add a missing colon before the password in PASS message, if the password
  has spaces or begins with a colon
  * irc: fix charset decoding in incoming private messages
  * irc: display the arrow before server name in raw buffer
  * irc: fix display of messages sent to server in raw buffer
  * irc: fix display of invalid UTF-8 chars in raw buffer
  * relay: display the arrow before client id and protocol in raw buffer
  * ruby: fix load of scripts requiring "uri"
  * ruby: fix Ruby detection when pkg-config is not installed
  * tests: fix locale used to execute tests
* Sun Aug 16 2015 mimi.vx@gmail.com
- Version bump to 1.3:
  * core: add completion "colors" (issue #481)
  * core: start/stop search in buffer at current scroll position by default, add
  key Ctrl+q to stop search and reset scroll (issue #76, issue #393)
  * core: add option weechat.look.key_grab_delay to set the default delay when
  grabbing a key with Alt+k
  * core: add option weechat.look.confirm_upgrade (issue #463)
  * core: allow Ctrl+c to exit WeeChat when the passphrase is asked on startup (issue #452)
  * core: allow pointer as list name in evaluation of hdata (issue #450)
  * core: add signal "signal_sighup"
  * api: add support of evaluated sub-strings and current date/time in function
  string_eval_expression() and command /eval
  * api: add function string_eval_path_home()
  * alias: add options "add", "addcompletion" and "del" in command /alias, remove
  command /unalias (issue #458)
  * irc: add option irc.network.channel_encode (issue #218, issue #482)
  * irc: add option irc.color.topic_current (issue #475)
  * irc: evaluate content of server option "nicks"
  * logger: evaluate content of option logger.file.path (issue #388)
  * relay: display value of HTTP header "X-Real-IP" for websocket connections (issue #440)
  * script: rename option script.scripts.dir to script.scripts.path, evaluate content
  of option (issue #388)
  * xfer: evaluate content of options xfer.file.download_path and xfer.file.upload_path (issue #388)
  * many bug fixes
* Tue Aug  4 2015 tchvatal@suse.com
- Ensure we use system CA ca-bundle.pem file by hardcoding it
- Remove patch:
  * weechat-capath.patch
* Sat Jul  4 2015 tchvatal@suse.com
- Version bump to 1.2:
  - add options to customize word chars (for detecting word boundaries)
  - add a welcome message on first WeeChat run
  - add options to customize quoted messages (in cursor mode)
  - add support of environment variables in evaluated expressions
  - add IRC SASL mechanism "ecdsa-nist256p-challenge"
  - add support of SHA-256 and SHA-512 algorithms in IRC server option "ssl_fingerprint"
  - add support of IRC capability "account-notify"
  - remove "freenode" server from default config
  - new script plugin for javascript
  - many bugs fixed.
- Refreshed patch:
  * weechat-capath.patch
* Mon Feb 16 2015 tchvatal@suse.com
- Version bump to 1.1.1:
  * core: fix random error when creating symbolic link weechat-curses on make install with cmake (bug #40313)
  * core: fix crash when a root bar has conditions different from active/inactive/nicklist (closes #317)
  * irc: don’t close channel buffer on second /part when option irc.look.part_closes_buffer is off (closes #313)
  * irc: fix /join on a channel buffer opened with autojoin but which failed to join
  * irc: send QUIT to server and no PART for channels when the server buffer is closed (closes #294)
  * irc: fix order of channel buffers opened when option irc.look.server_buffer is set to "independent", irc.look.buffer_open_before_autojoin to "on" and irc.look.new_channel_position to "near_server" (closes #303)
  * irc: fix crash in buffer close when server name is the same as a channel name (closes #305)
* Wed Jan 28 2015 tchvatal@suse.com
- Recommend lang package and perl/python scripting support as
  bare iron weechat is bit boring
* Wed Jan 28 2015 tchvatal@suse.com
- Make this build on SLE12
* Mon Jan 12 2015 tchvatal@suse.com
- Version bump to 1.1:
  - complete inline commands in input
  - allow incomplete commands if unambiguous
  - improve speed of completions
  - add bar item and signals for mouse status
  - use bar conditions on root bars
  - add option "reorder" in command /server
  - open irc channel buffers before the join is received from server
  - add server option "sasl_fail"
  - add support for color codes 16-99 in IRC messages
  - disable SSLv3 by default
  - add support of IRC capability "extended-join"
  - add options "stop" and "start" in command /relay
  - use HTTPS by default in script plugin for downloads
  - add option "restore" in command /trigger
  - evaluate and replace regex groups at same time in trigger (new and
    incompatible format)
  - many bugs fixed.
* Thu Nov 20 2014 tchvatal@suse.com
- Remove sle11 support as now I don't need it anymore
- Use %%cmake macro properly
- Document that there are tests that need extra pkg
- Split documentation into -doc subpackage
* Fri Oct 10 2014 gber@opensuse.org
- update toversion 1.0.1
  - this is a bug fix and maintenance release
  - for complete list of bugs fixed, please look at ChangeLog
* Sat Aug 16 2014 gber@opensuse.org
- update to version 1.0
  - plugin "trigger": Swiss Army knife for WeeChat (replaces
    "rmodifier" plugin)
  - plugin "exec": execute external commands (replaces script
    "shell.py")
  - bare display: easy click on long URLs and text selection with
    mouse
  - support of environment variables in /set command
  - hidden buffers
  - negated tags in filters
  - toggle of filters in specific buffers
  - flexible conditions for adding/removing buffers in hotlist
  - text search in buffers with free content
  - support of wildcard "*" inside masks
  - support of nested variables in evaluated expressions
  - tag with host in IRC messages displayed
  - support of "away-notify" IRC capability
  - IRC commands: /allpv, /remove, /unquiet
  - bar items: buffer_short_name, irc_nick_modes
  - unit tests
  - many bugs fixed
- drop obsolete weechat-link-pthread.patch
* Mon Jun 23 2014 tchvatal@suse.com
- Make the thing build again on SLE11 as we use it in SUSE on
  server :)
* Mon May 26 2014 gber@opensuse.org
- update to version 0.4.3
  - new command /print
  - logical and/or for tags in /filter and hook_print
  - gaps in buffer numbers
  - support of italic text
  - new options to customize default text search in buffers
  - use of IRC monitor command for /notify (if available on server)
  - new IRC server option "ssl_fingerprint"
  - new option to smart-filter IRC mode messages
  - new option for default IRC ban mask
  - support of IPv6 for DCC chat/file
  - auto check CRC32 of files received with DCC
  - many bugs fixed
- add weechat-link-pthread.patch in order to link Weechat against
  libpthread fixing freezes/crashes with gnutls (backported from
  upstream git)
* Mon Oct  7 2013 gber@opensuse.org
- remove support for < 12.2
* Mon Oct  7 2013 gber@opensuse.org
- update to version 0.4.2
  * rename binary from "weechat-curses" to "weechat" (with symbolic
    link "weechat-curses" for compatibility)
  * add secured data (encryption of passwords or private data), new
    command /secure, new file sec.conf
  * search of regular expression in buffer with text emphasis, in
    prefixes, messages or both
  * add option "scroll_beyond_end" for command /window
  * add optional buffer context in bar items (for example to
    display bitlbee nicklist in a root bar)
  * new options weechat.look.hotlist_{prefix|suffix}
  * new option weechat.look.key_bind_safe to prevent any key
    binding error from user
  * new option weechat.network.proxy_curl to use a proxy when
    downloading URLs with curl
  * display day change message dynamically
  * support of wildcards in IRC commands (de)op/halfop/voice
  * new option irc.look.notice_welcome_redirect to redirect channel
    welcome notices to the channel buffer
  * new option irc.look.nick_color_hash: new hash algorithm to find
    nick colors (variant of djb2)
  * add info about things defined by a script in the detailed view
    of script (/script show)
  * support of "enchant" library in aspell plugin
  * many bugs fixed.
- rebased weechat-0.4.1-capath.diff and renamed to
  weechat-capath.patch
- build aspell plugin with enchant support
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Tue Aug  6 2013 lnussel@suse.de
- use system's default certificate store instead of hardcoding the
  path to a bundle file (weechat-0.4.1-capath.diff, bnc#829471)
* Tue May 21 2013 gber@opensuse.org
- update to version 0.4.1
  * multiple layouts support
  * nick prefix/suffix are now dynamic (and managed by core instead
    of irc plugin)
  * unmask irc join if nick speaks some minutes after the join
  * new option irc.look.display_join_message to disable some
    messages after joining a channel
  * new option irc.look.pv_buffer to automatically merge private
    buffers
  * add support of UHNAMES
  * add DH-AES encryption method for SASL
  * multiple irc servers allowed on same port for irc protocol in
    relay plugin
  * add WebSocket server support (RFC 6455) in relay plugin (for
    irc and weechat protocols)
  * send nicklist difference in relay plugin (weechat protocol)
  * add control of autoload for scripts
  * optimizations in aspell plugin
  * many bugs fixed.
* Mon Jan 21 2013 tchvatal@suse.com
- Version bump to version 0.4.0:
  * add option "diff" for command /set, display default values in output of /set
  * add color support in prefix options
  * add command /eval, use expression in conditions for bars
  * connect by default with IPv6 to servers with fallback to IPv4
  * add aspell suggestions
  * add support of tags in irc messages and "server-time" capability
  * add irc command /quiet
  * add support of IPv6 in relay plugin
  * add backlog for irc protocol in relay plugin
  * display remote IP address for DCC chat/file in xfer plugin
  * add git version in build
  * many bugs fixed.
* Mon Nov 19 2012 gber@opensuse.org
- update to version 0.3.9.2:
  * fix possible shell injection vulnerability in hook_process
    function (bnc#790217)
* Sat Nov 10 2012 gber@opensuse.org
- update to version 0.3.9.1:
  * fix buffer overflow when decoding IRC colors in strings
* Sun Sep 30 2012 gber@opensuse.org
- update to version 0.3.9:
  * add plugin "script" (replacement of weeget.py and script.pl)
  * add support of SSL in relay plugin
  * add color for offline nicks
  * add system resource limits for WeeChat process
  * add zoom on merged buffer (default key: alt+"x")
  * add "Day changed to" in logger backlog
  * add command line option "-r" (or "--run-command") to run
    command(s) after startup of WeeChat
  * add option "swap" for command /buffer
  * generate alternate IRC nicks dynamically (when all nicks are
    already in use)
  * fix rejoin of password protected IRC channels
  * fix freeze in irc and relay plugins with sockets
  * allow update for some variables of hdata
  * add japanese user's guide, scripting guide and tester's guide
  * many bugs fixed
- drop obsolete weechat-fix-cmake-guile.patch
* Mon Jun  4 2012 gber@opensuse.org
- enable guile scripting support introduced in 0.3.7
- dropped unnecessary weechat-0.3.3-fix-strftime.patch
- added weechat-fix-cmake-guile.patch which fixes the include dir
  for guile no being passed to the guild script plugin cmake file
* Mon Jun  4 2012 gber@opensuse.org
- update to version 0.3.8:
  * add terminal "bracketed paste mode"
  * add IRC "external" SASL mechanism
  * improve parsing of IRC channel modes (do not send extra command
    "MODE" to server)
  * follow symbolic links for configuration files (*.conf)
  * new option weechat.look.prefix_same_nick (hide same prefix for
    multiple consecutive messages from same nick)
  * add colors for backlog lines
  * redirect IRC messages from clients to hide output (relay
    plugin, IRC protocol)
  * add a connection timeout for child process in hook_connect
  * fix display bugs and crashs with small windows
  * fix truncated configuration files (zero-length) after system
    crash
  * many bugs fixed.
* Mon May 21 2012 badshah400@gmail.com
- Use BuildRequires: libgnutls-devel instead of gnutls-devel for
  Factory in keeping with gnutls package naming changes.
* Sun Feb 26 2012 pascal.bleser@opensuse.org
- update to 0.3.7:
  * adds support for scheme scripts (with GNU guile)
  * adds support for Python 3.x
  * adds remote interfaces using a relay plugin (like QWeeChat, a Python/Qt remote interface)
  * adds URL transfers in the API
  * option `scroll_unread` has been moved from command `/input` to `/window`,
    therefore default command of key alt-u has been updated. To bind key with
    new default value: `/key bind meta-u /window scroll_unread`
  * extended regex is used in filters and irc ignore, so some chars that needed
    escape in past do not need any more (for example `[0-9]\+` becomes
    `[0-9]+`), filters and ignore have to be manually fixed
  * option 'weechat.look.highlight_regex' becomes case insensitive by default,
    to make it case sensitive, use "(?-i)" at beginning of string, for example:
    "(?-i)FlashCode|flashy"
  * option 'weechat.history.max_lines' has been renamed to
    'weechat.history.max_buffer_lines_number'
* Sun Jan  8 2012 gber@opensuse.org
- clean up build dependencies
- build against lua51 for > 12.1
* Fri Dec  9 2011 coolo@suse.com
- the COPYING says GPL-3.0+
* Sun Oct 23 2011 gber@opensuse.org
- removed weechat-remove_build_timestamp.patch and use previous
  code again to deal with timestamps
* Sat Oct 22 2011 pascal.bleser@opensuse.org
- update to 0.3.6:
  * mouse support
  * cursor mode (free movement of cursor on screen)
  * contexts for keys (default, search, cursor, mouse)
  * hdata in API (direct access to WeeChat data)
  * "inactive" colors for inactive windows and lines in merged
    buffers
  * support of merged buffers in /layout, save layout of
    buffers/windows on /upgrade
  * horizontal scrolling in buffers with free content
  * split of outgoing IRC messages
  * options for "more" chars in bars
  * bold not used any more for basic colors (if terminal has more
    than 16 colors)
  * automatic zoom on current window when terminal becomes too
    small for windows
  * new command /repeat
  * local variable "highlight_regex" in buffers
- added weechat-remove_build_timestamp.patch
* Mon May 16 2011 gber@opensuse.org
- update to version 0.3.5:
  * 256 colors support improved (dynamic allocation of colors)
  * attributes for colors (bold/reverse/underline)
  * better scroll of input (with long text)
  * output of /help improved for list of commands and their
    arguments
  * remember scroll position of buffers in windows
  * list of buffers in filters
  * count of messages in hotlist buffers
  * swap buffers of windows
  * balance of windows
  * new API function to set help on plugin/script options
  * speller options in aspell plugin
  * option for SSL priorities in IRC servers
  * color nicks in nicklist and output of /names
- dropped weechat-0.3.4-fix-array-overflow.patch which has been
  included upstream
* Wed Mar 23 2011 gber@opensuse.org
- dropped weechat-0.3.4-remove-date-time.patch, use date/time from
  last changelog entry rather than removing it completely
- use %%desktop_database_post/un
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Thu Feb 17 2011 gber@opensuse.org
- added weechat-0.3.4-fix-array-overflow.patch which fixes an
  array overflow
* Sun Jan 16 2011 pascal.bleser@opensuse.org
- update to 0.3.4:
  * adds 256-color support
  * adds IRC proxy support
  * adds redirection of IRC commands
  * adds new /notify command
  * adds the rmodifier plugin
  * adds regular expression support for highlights
  * adds sharing of the input line between buffers
  * many bugfixes
* Mon Nov  8 2010 gber@opensuse.org
- cleanup
  * added specfile header
  * added more accurate summary and description
  * removed support for obsolete openSUSE versions
  * split off -lang subpackage
  * added patch to remove __DATE__ and __TIME__ macros
  * enabled make output
  * build with $RPM_OPT_FLAGS
* Mon Oct 11 2010 gber@opensuse.org
- fixed build for Python > 2.6
* Sun Aug  8 2010 pascal.bleser@opensuse.org
- update to 0.3.3:
  * new features:
    + keys to undo/redo changes on the command line
    + a better lag indicator
    + the /wallchops IRC command
    + display of messages in IRC private buffers when the nick is back on a server after a /quit
    + reverse regex in a filter
    + hash tables in the plugin API
  * many bugfixes
* Sun Apr 18 2010 pascal.bleser@opensuse.org
- update to 0.3.2:
  * add SASL authentication with IRC servers
  * add new commands /mute and /map
  * add custom completion for aliases
  * add date format in log filenames
  * autoloading of plugins was improved
  * many bugs were fixed
* Sun Jan 31 2010 pascal.bleser@opensuse.org
- update to 0.3.1.1:
  * fixes crashes with SSL connection and purge of old DCC chats
* Sat Jan 23 2010 pascal.bleser@opensuse.org
- update to 0.3.1:
  * new features
  * options were added to customize CTCP replies and the target
    buffer for IRC messages
  * SSL certificates are now checked
  * CertFP was added for automatic identification on servers
  * anti-flood measures were improved
  * new expansions were added for alias arguments
  * many bugs were fixed
* Sun Sep 13 2009 pascal.bleser@opensuse.org
- update to 0.3.0:
  * externalization of IRC as a plugin
  * new display engine (faster)
  * NES plugins
  * new plugin API
  * buffers with free content
  * dynamic filtering
  * smart join/part/quit filter
  * custom bars with custom items
  * buffer merging
  * group support in nicklist
  * less CPU usage
* Fri Jun 12 2009 pascal.bleser@opensuse.org
- update to 0.2.6.3:
  * fixes a bug with detection of the gnutls library
* Sat Apr 18 2009 pascal.bleser@opensuse.org
- update to 0.2.6.2:
  * fixes a charset decoding problem
* Mon Mar 16 2009 pascal.bleser@opensuse.org
- update to 0.2.6.1:
  * fixes a crash with some special characters in IRC messages
* Wed Sep  5 2007 guru@unixtech.be
- update to 0.2.6
* Fri Jun  8 2007 guru@unixtech.be
- initial build service submission
